crd

package
v0.0.0-...-eec02a6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 15, 2026 License: Apache-2.0 Imports: 33 Imported by: 0

Documentation

Index

Constants

const (
	EventAdd         = crdtypes.EventAdd
	EventUpdate      = crdtypes.EventUpdate
	EventForceUpdate = crdtypes.EventForceUpdate
	EventDelete      = crdtypes.EventDelete

	OjbectTypeTridentVolumePublication = crdtypes.ObjectTypeTridentVolumePublication
	ObjectTypeTridentBackend           = crdtypes.ObjectTypeTridentBackend
	ObjectTypeTridentAutogrowPolicy    = crdtypes.ObjectTypeTridentAutogrowPolicy
	ObjectTypeStorageClass             = crdtypes.ObjectTypeStorageClass
	ObjectTypeTridentVolumeMove        = crdtypes.ObjectTypeTridentVolumeMove

	OperationStatusSuccess string = "Success"
	OperationStatusFailed  string = "Failed"
)

Variables

This section is empty.

Functions

func Logx

func Logx(ctx context.Context) LogEntry

Types

type EventType

type EventType = crdtypes.EventType

type KeyItem

type KeyItem struct {
	// contains filtered or unexported fields
}

type ObjectType

type ObjectType = crdtypes.ObjectType

type TridentNodeCrdController

type TridentNodeCrdController struct {
	// contains filtered or unexported fields
}

TridentNodeCrdController is the controller implementation for Trident's Node CRD resources handling

func NewTridentNodeCrdController

func NewTridentNodeCrdController(
	masterURL, kubeConfigPath, nodeName string, plugin *csi.Plugin, autogrowPeriod time.Duration,
) (*TridentNodeCrdController, error)

NewTridentNodeCrdController returns a new Trident Node CRD controller frontend

func (*TridentNodeCrdController) Activate

func (c *TridentNodeCrdController) Activate() error

func (*TridentNodeCrdController) Deactivate

func (c *TridentNodeCrdController) Deactivate() error

func (*TridentNodeCrdController) GetName

func (c *TridentNodeCrdController) GetName() string

func (*TridentNodeCrdController) Run

func (c *TridentNodeCrdController) Run(ctx context.Context, threadiness int, stopCh <-chan struct{})

Run will set up the event handlers for types we are interested in, as well as syncing informer caches and starting workers. It will block until stopCh is closed, at which point it will shutdown the workqueue and wait for workers to finish processing their current work items.

func (*TridentNodeCrdController) Version

func (c *TridentNodeCrdController) Version() string

Jump to