Documentation
¶
Index ¶
- Constants
- func Logx(ctx context.Context) LogEntry
- type EventType
- type KeyItem
- type ObjectType
- type TridentNodeCrdController
- func (c *TridentNodeCrdController) Activate() error
- func (c *TridentNodeCrdController) Deactivate() error
- func (c *TridentNodeCrdController) GetName() string
- func (c *TridentNodeCrdController) Run(ctx context.Context, threadiness int, stopCh <-chan struct{})
- func (c *TridentNodeCrdController) Version() string
Constants ¶
const ( EventAdd = crdtypes.EventAdd EventUpdate = crdtypes.EventUpdate EventForceUpdate = crdtypes.EventForceUpdate EventDelete = crdtypes.EventDelete OjbectTypeTridentVolumePublication = crdtypes.ObjectTypeTridentVolumePublication ObjectTypeTridentBackend = crdtypes.ObjectTypeTridentBackend ObjectTypeTridentAutogrowPolicy = crdtypes.ObjectTypeTridentAutogrowPolicy ObjectTypeStorageClass = crdtypes.ObjectTypeStorageClass ObjectTypeTridentVolumeMove = crdtypes.ObjectTypeTridentVolumeMove OperationStatusSuccess string = "Success" OperationStatusFailed string = "Failed" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ObjectType ¶
type ObjectType = crdtypes.ObjectType
type TridentNodeCrdController ¶
type TridentNodeCrdController struct {
// contains filtered or unexported fields
}
TridentNodeCrdController is the controller implementation for Trident's Node CRD resources handling
func NewTridentNodeCrdController ¶
func NewTridentNodeCrdController( masterURL, kubeConfigPath, nodeName string, plugin *csi.Plugin, autogrowPeriod time.Duration, ) (*TridentNodeCrdController, error)
NewTridentNodeCrdController returns a new Trident Node CRD controller frontend
func (*TridentNodeCrdController) Activate ¶
func (c *TridentNodeCrdController) Activate() error
func (*TridentNodeCrdController) Deactivate ¶
func (c *TridentNodeCrdController) Deactivate() error
func (*TridentNodeCrdController) GetName ¶
func (c *TridentNodeCrdController) GetName() string
func (*TridentNodeCrdController) Run ¶
func (c *TridentNodeCrdController) Run(ctx context.Context, threadiness int, stopCh <-chan struct{})
Run will set up the event handlers for types we are interested in, as well as syncing informer caches and starting workers. It will block until stopCh is closed, at which point it will shutdown the workqueue and wait for workers to finish processing their current work items.
func (*TridentNodeCrdController) Version ¶
func (c *TridentNodeCrdController) Version() string
Click to show internal directories.
Click to hide internal directories.